// /qt/qml/org/kde/plasma/components/Page.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qalgorithms.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qrandom.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <cmath>
#include <limits>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_plasma_components_Page_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xdc,0x7,0x0,0x0,0xbc,0xf9,0xbd,0x13,
0x8d,0xe5,0xfa,0xfc,0x8e,0xeb,0xbb,0xdd,
0xab,0xe2,0xb,0x6c,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0xe0,0x2,0x0,0x0,
0x2,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x7,0x0,0x0,
0x30,0x1,0x0,0x0,0xe8,0x1,0x0,0x0,
0x93,0x0,0x0,0x0,0xb3,0x0,0x0,0x0,
0xc3,0x0,0x0,0x0,0xd3,0x0,0x0,0x0,
0xe3,0x0,0x0,0x0,0xf3,0x0,0x0,0x0,
0x3,0x1,0x0,0x0,0x13,0x1,0x0,0x0,
0x23,0x1,0x0,0x0,0xa4,0x0,0x0,0x0,
0x93,0x0,0x0,0x0,0x33,0x1,0x0,0x0,
0x43,0x1,0x0,0x0,0x53,0x1,0x0,0x0,
0x63,0x1,0x0,0x0,0x73,0x1,0x0,0x0,
0x83,0x1,0x0,0x0,0x93,0x1,0x0,0x0,
0x93,0x1,0x0,0x0,0xa3,0x1,0x0,0x0,
0xb3,0x1,0x0,0x0,0xb3,0x1,0x0,0x0,
0xa3,0x1,0x0,0x0,0xa4,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2c,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2e,0x0,0x18,0x7,0x2e,0x1,0x18,0xe,
0x2e,0x2,0x80,0xe,0x18,0xf,0x2e,0x3,
0x80,0xf,0x18,0xa,0x2e,0x4,0x18,0xe,
0x2e,0x5,0x80,0xe,0x18,0xf,0x2e,0x6,
0x80,0xf,0x18,0xb,0x2e,0x7,0x18,0xc,
0x2e,0x8,0x18,0xd,0xac,0x9,0x7,0x4,
0xa,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x98,0x0,0x0,0x0,0x5c,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0xff,0xff,0xff,0xff,0x12,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x3c,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x50,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x5b,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2e,0xa,0x18,0x7,0x2e,0xb,0x18,0xc,
0x2e,0xc,0x80,0xc,0x18,0xd,0x2e,0xd,
0x80,0xd,0x18,0xa,0x2e,0xe,0x18,0xc,
0x2e,0xf,0x80,0xc,0x18,0xd,0x2e,0x10,
0x80,0xd,0x18,0xe,0x2e,0x11,0x18,0xf,
0x6,0x64,0xf,0x50,0xa,0x2e,0x12,0x18,
0x10,0x2e,0x13,0x80,0x10,0x4c,0x1,0x6,
0x80,0xe,0x18,0xf,0x2e,0x14,0x18,0x10,
0x6,0x64,0x10,0x50,0xa,0x2e,0x15,0x18,
0x11,0x2e,0x16,0x80,0x11,0x4c,0x1,0x6,
0x80,0xf,0x18,0xb,0xac,0x17,0x7,0x2,
0xa,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x50,0x3,0x0,0x0,0x58,0x3,0x0,0x0,
0x70,0x3,0x0,0x0,0x78,0x3,0x0,0x0,
0xa0,0x3,0x0,0x0,0xb8,0x3,0x0,0x0,
0xd8,0x3,0x0,0x0,0x18,0x4,0x0,0x0,
0x40,0x4,0x0,0x0,0x80,0x4,0x0,0x0,
0x90,0x4,0x0,0x0,0xa0,0x4,0x0,0x0,
0xd8,0x4,0x0,0x0,0xf0,0x4,0x0,0x0,
0x10,0x5,0x0,0x0,0x30,0x5,0x0,0x0,
0x50,0x5,0x0,0x0,0x70,0x5,0x0,0x0,
0xa0,0x5,0x0,0x0,0xd0,0x5,0x0,0x0,
0x8,0x6,0x0,0x0,0x20,0x6,0x0,0x0,
0x40,0x6,0x0,0x0,0x60,0x6,0x0,0x0,
0x80,0x6,0x0,0x0,0xa0,0x6,0x0,0x0,
0xd0,0x6,0x0,0x0,0xe8,0x6,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x54,0x0,0x65,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x73,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x54,0x0,0x2e,0x0,
0x50,0x0,0x61,0x0,0x67,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4d,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x6d,0x0,0x61,0x0,
0x78,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x42,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x57,0x0,0x69,0x0,0x64,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x49,0x0,0x6e,0x0,
0x73,0x0,0x65,0x0,0x74,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x49,0x0,
0x6e,0x0,0x73,0x0,0x65,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x50,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x50,0x0,
0x61,0x0,0x64,0x0,0x64,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x57,0x0,0x69,0x0,0x64,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x46,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x57,0x0,0x69,0x0,0x64,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x42,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x48,0x0,0x65,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x49,0x0,0x6e,0x0,0x73,0x0,
0x65,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6d,0x0,
0x49,0x0,0x6e,0x0,0x73,0x0,0x65,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x50,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6d,0x0,
0x50,0x0,0x61,0x0,0x64,0x0,0x64,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x48,0x0,0x65,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x73,0x0,0x70,0x0,
0x61,0x0,0x63,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x46,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x48,0x0,0x65,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x3c,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0xf,0x0,0x10,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x14,0x0,0x50,0x1,
0x5,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x10,0x0,0x40,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitWidth at line 16, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
double v2_10;
double v2_14;
double v2_16;
double v2_20;
double v2_24;
double v2_26;
double v2_30;
double v2_32;
double v2_36;
double v2_40;
double v2_44;
double v2_4;
double v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(2, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_10 = (s.v2_4 + s.v2_8);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(3, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadScopeObjectPropertyLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_16 = (s.v2_10 + s.v2_14);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(4, &s.v2_20)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
aotContext->initLoadScopeObjectPropertyLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(5, &s.v2_24)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initLoadScopeObjectPropertyLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_26 = (s.v2_20 + s.v2_24);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(6, &s.v2_30)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
aotContext->initLoadScopeObjectPropertyLookup(6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_32 = (s.v2_26 + s.v2_30);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(7, &s.v2_36)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initLoadScopeObjectPropertyLookup(7);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(8, &s.v2_40)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
aotContext->initLoadScopeObjectPropertyLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_16;
const double arg2 = s.v2_32;
const double arg3 = s.v2_36;
const double arg4 = s.v2_40;
s.v2_44 = [&]() { 
auto  tmpMax = (qIsNull(arg2) && qIsNull(arg1) && std::copysign(1.0, arg2) == 1) ? arg2 : ((arg2 > arg1 || std::isnan(arg2)) ? arg2 : arg1);
	tmpMax = (qIsNull(arg3) && qIsNull(tmpMax) && std::copysign(1.0, arg3) == 1) ? arg2 : ((arg3 > tmpMax || std::isnan(arg3)) ? arg3 : tmpMax);
	tmpMax = (qIsNull(arg4) && qIsNull(tmpMax) && std::copysign(1.0, arg4) == 1) ? arg2 : ((arg4 > tmpMax || std::isnan(arg4)) ? arg4 : tmpMax);
return tmpMax;
}();
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_44;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitHeight at line 20, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
bool v2_41;
bool v2_65;
double c2_56;
double c2_80;
double v2_10;
double v2_14;
double v2_16;
double v2_20;
double v2_24;
double v2_26;
double v2_30;
double v2_32;
double v2_36;
double v2_40;
double v2_45;
double v2_49;
double v2_4;
double v2_51;
double v2_55;
double v2_56;
double v2_60;
double v2_64;
double v2_69;
double v2_73;
double v2_75;
double v2_79;
double v2_80;
double v2_84;
double v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(11, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(12, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadScopeObjectPropertyLookup(12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_10 = (s.v2_4 + s.v2_8);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(13, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadScopeObjectPropertyLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_16 = (s.v2_10 + s.v2_14);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(14, &s.v2_20)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(22);
#endif
aotContext->initLoadScopeObjectPropertyLookup(14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(15, &s.v2_24)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initLoadScopeObjectPropertyLookup(15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_26 = (s.v2_20 + s.v2_24);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(16, &s.v2_30)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
aotContext->initLoadScopeObjectPropertyLookup(16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_32 = (s.v2_26 + s.v2_30);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(17, &s.v2_36)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initLoadScopeObjectPropertyLookup(17);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_40 = double(0);
{
}
// generate_CmpGt
s.v2_41 = s.v2_36 > s.v2_40;
{
}
// generate_JumpFalse
if (!s.v2_41) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(47);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(18, &s.v2_45)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(47);
#endif
aotContext->initLoadScopeObjectPropertyLookup(18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(51);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(19, &s.v2_49)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(51);
#endif
aotContext->initLoadScopeObjectPropertyLookup(19);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_51 = (s.v2_45 + s.v2_49);
{
}
// generate_Jump
{
s.c2_56 = s.v2_51;
    goto label_1;
}
label_0:;
// generate_LoadZero
s.v2_55 = double(0);
{
s.c2_56 = s.v2_55;
}
label_1:;
// generate_Add
s.v2_56 = (s.v2_32 + s.c2_56);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(62);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(20, &s.v2_60)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(62);
#endif
aotContext->initLoadScopeObjectPropertyLookup(20);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_64 = double(0);
{
}
// generate_CmpGt
s.v2_65 = s.v2_60 > s.v2_64;
{
}
// generate_JumpFalse
if (!s.v2_65) {
    goto label_2;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(71);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(21, &s.v2_69)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(71);
#endif
aotContext->initLoadScopeObjectPropertyLookup(21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(75);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(22, &s.v2_73)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(75);
#endif
aotContext->initLoadScopeObjectPropertyLookup(22);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Add
s.v2_75 = (s.v2_69 + s.v2_73);
{
}
// generate_Jump
{
s.c2_80 = s.v2_75;
    goto label_3;
}
label_2:;
// generate_LoadZero
s.v2_79 = double(0);
{
s.c2_80 = s.v2_79;
}
label_3:;
// generate_Add
s.v2_80 = (s.v2_56 + s.c2_80);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_16;
const double arg2 = s.v2_80;
s.v2_84 = [&]() { 
auto  tmpMax = (qIsNull(arg2) && qIsNull(arg1) && std::copysign(1.0, arg2) == 1) ? arg2 : ((arg2 > arg1 || std::isnan(arg2)) ? arg2 : arg1);
return tmpMax;
}();
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_84;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
